@@ -13,6 +13,14 @@ sub scrape {
   my ($self, $html) = @_;
 
   my %scraper;
+  $scraper{images} = scraper {
+    process 'a',
+      link => '@onClick';
+    process 'a>img',
+      thumb_link => '@src';
+    result qw( link thumb_link );
+  };
+
   $scraper{diary_body} = scraper {
     process 'tr[valign="top"]>td[nowrap]',
       time => 'TEXT';
@@ -20,7 +28,9 @@ sub scrape {
       subject => 'TEXT';
     process 'tr>td>table[width="410"]>tr>td[class="h12"]',
       description => 'TEXT';
-    result qw( time subject description );
+    process 'tr>td>table[width="410"]>tr>td>table>tr>td[valign="middle"]',
+      'images[]' => $scraper{images};
+    result qw( time subject description images );
   };
 
   $scraper{diary} = scraper {
@@ -31,6 +41,11 @@ sub scrape {
 
   my $stash = $self->post_process($scraper{diary}->scrape(\$html))->[0];
 
+  # XXX: this fails when you test with local files.
+  # However, this link cannot be extracted from the html,
+  # at least as of writing this. ugh.
+  $stash->{link} = $self->{uri};
+
   $scraper{comments} = scraper {
     process 'tr',
       string => 'TEXT';
@@ -39,7 +54,7 @@ sub scrape {
     process 'td[width="430"]>table[width="410"]>tr>td>a',
       link => '@href',
       name => 'TEXT';
-    process 'td[bgcolor="#ffffff"]>table[cellpadding="3"]>tr>td[class="h12"]',
+    process 'td[bgcolor="#ffffff"]>table[cellpadding="5"]>tr>td[class="h12"]',
       description => 'TEXT';
     result qw( string time link name description );
   };
@@ -95,6 +110,12 @@ returns a hash reference such as
     subject => 'title of the entry',
     time => 'yyyy-mm-dd hh:mm',
     description => 'entry body',
+    images => [
+      {
+        link => 'show_diary_picture.pl?img_src=http://img1.mixi.jp/photo/xx/xx.jpg',
+        thumb_link => 'http://img1.mixi.jp/photo/xx/xx.jpg',
+      },
+    ],
     comments => [
       {
         name => 'commenter',
